@@ -48,38 +48,6 @@ def fetch_generator(c):
         yield tup
 
 
-def first_not_empty(lst):
-    val = None
-    for v in lst:
-        val = v
-        if v is not None and not (isinstance(v, list) and len(v) == 0):
-            return v
-    else:
-        return val
-        
-def limited(iterable, n):
-    for f in iterable:
-        if n is None:
-            yield f
-        else:
-            if n or n > 0:
-                yield f
-            else:
-                break
-            n -= 1
-            
-def strided(iterable, n, i=0):
-    for j, f in enumerate(iterable):
-        if j%n == i:
-            yield f
-            
-def skipped(iterable, n):
-    for f in iterable:
-        if n > 0:
-            n -= 1
-        else:
-            yield f
-            
 class MetaValidationError(Exception):
     
     def __init__(self, message, errors):
