@@ -4,7 +4,7 @@ from urllib.parse import quote_plus, unquote_plus
 from metacat.util import to_bytes, to_str
 from metacat.webapi import MetaCatClient, MCServerError, MCWebAPIError, MCError
 from metacat.ui.cli import CLICommand, InvalidArguments, InvalidOptions
-
+from metacat.mql import MQLQuery
 
 Usage = """
 Usage: --
@@ -31,9 +31,9 @@ class QueryCommand(CLICommand):
 
     GNUStyle = False    
     Opts = (
-        "jism:N:pq:S:A:lP", 
+        "jism:N:pq:S:A:lPx", 
         ["line", "json", "ids", "summary", "metadata=", "namespace=", "pretty",
-            "with-provenance", "save-as=", "add-to="
+            "with-provenance", "save-as=", "add-to=", "explain"
         ]
     )
     Usage = """[<options>] (-q <MQL query file>|"<MQL query>")
@@ -52,6 +52,8 @@ class QueryCommand(CLICommand):
             -N|--namespace=<default namespace>  - default namespace for the query
             -S|--save-as=<namespace>:<name>     - save files as a new datset
             -A|--add-to=<namespace>:<name>      - add files to an existing dataset
+            
+            -x|--explain                        - dp not run the query, show resulting SQL only
     """
     
     def __call__(self, command, client, opts, args):
@@ -72,49 +74,70 @@ class QueryCommand(CLICommand):
             if not query_file:
                 raise InvalidArguments("Query must be specified")
             query_text = to_str(open(query_file, "r").read())
+            
+        if "-x" in opts or "--explain" in opts:
+            print("---- Query text ----\n%s\n" % (query_text,))
+            q = MQLQuery.parse(query_text, loader=client)
+
+            print("---- Parsed ----")
+            print(q.Parsed.pretty())
+            print("")
+
+            print("---- Converted ----")
+            print(q.Tree.pretty("    "))
+            print("")
         
-        results = client.query(query_text, namespace=namespace, with_metadata = with_meta, 
-                    save_as=save_as, add_to=add_to,
-                    with_provenance=with_provenance)
-
-        if "--json" in opts or "-j" in opts:
-            print(json.dumps(results, sort_keys=True, indent=4, separators=(',', ': ')))
-            sys.exit(0)
-
-        if "--pretty" in opts or "-p" in opts:
-            meta = sorted(results, key=lambda x: x["name"])
-            pprint.pprint(meta)
-            sys.exit(0)
-
-        in_line = "-l" in opts or "--line" in opts
-
-        #print("response results:", results)
+            #q.optimize(False)
+            #print("---- Optimized ----")
+            #print(q.Optimized.pretty("    "))
+            #print("")
     
-        if "-s" in opts or "--summary" in opts and not with_meta:
-            print("%d files" % (len(results),))
+            compiled = q.compile()
+            print("---- Compiled ----")
+            print(compiled.pretty("    "))
         else:
-            for f in results:
-                meta_lst = []
-                meta_out = ""
-                if with_meta:
-                    meta = f["metadata"]
-                    klist = sorted(list(meta.keys())) if keys == "all" else keys
-                    if in_line:
-                        for k in klist:
-                            if k in meta:
-                                meta_lst.append("%s=%s" % (k, repr(meta[k])))
-                    else:
-                        for k in klist:
-                            if k in meta:
-                                meta_lst.append("%s\t=\t%s" % (k, repr(meta[k])))
-                    if meta_lst:
+            results = client.query(query_text, namespace=namespace, with_metadata = with_meta, 
+                        save_as=save_as, add_to=add_to,
+                        with_provenance=with_provenance)
+
+            if "--json" in opts or "-j" in opts:
+                print(json.dumps(results, sort_keys=True, indent=4, separators=(',', ': ')))
+                sys.exit(0)
+
+            if "--pretty" in opts or "-p" in opts:
+                meta = sorted(results, key=lambda x: x["name"])
+                pprint.pprint(meta)
+                sys.exit(0)
+
+            in_line = "-l" in opts or "--line" in opts
+
+            #print("response results:", results)
+    
+            if "-s" in opts or "--summary" in opts and not with_meta:
+                print("%d files" % (len(results),))
+            else:
+                for f in results:
+                    meta_lst = []
+                    meta_out = ""
+                    if with_meta:
+                        meta = f["metadata"]
+                        klist = sorted(list(meta.keys())) if keys == "all" else keys
                         if in_line:
-                            meta_out = "\t"+"\t".join(meta_lst)
+                            for k in klist:
+                                if k in meta:
+                                    meta_lst.append("%s=%s" % (k, repr(meta[k])))
                         else:
-                            meta_out += "\n    "+"\n    ".join(meta_lst)
-                if "--ids" in opts or "-i" in opts:
-                    print("%s%s" % (f["fid"],meta_out))
-                else:
-                    print("%s:%s%s" % (f["namespace"], f["name"], meta_out))
+                            for k in klist:
+                                if k in meta:
+                                    meta_lst.append("%s\t=\t%s" % (k, repr(meta[k])))
+                        if meta_lst:
+                            if in_line:
+                                meta_out = "\t"+"\t".join(meta_lst)
+                            else:
+                                meta_out += "\n    "+"\n    ".join(meta_lst)
+                    if "--ids" in opts or "-i" in opts:
+                        print("%s%s" % (f["fid"],meta_out))
+                    else:
+                        print("%s:%s%s" % (f["namespace"], f["name"], meta_out))
 
 QueryInterpreter = QueryCommand()
\ No newline at end of file
