@@ -2,4 +2,5 @@ from .py3 import PY2, PY3, to_str, to_bytes
 from .timelib import epoch
 from .trace import Tracer
 from .object_spec import ObjectSpec, undid
-from .utils import chunked, limited, unique, first_not_empty, strided, skipped
+from .utils import chunked, limited, unique, first_not_empty, strided, skipped, insert_sql
+from .validation import validate_metadata
